```@meta
CurrentModule = CRRao
```
Documentation for [CRRao](https://github.com/xKDR/CRRao.jl).

# CRRao

CRRao is a package that implements statistical models. The implementation 
of statistical models becomes straightforward for most Julia users 
with the help of this package. This is going to be a wrapper package;
leveraging the strength of wonderful Julia packages that already exist, 
such as [StatsBase.jl](https://github.com/JuliaStats/StatsBase.jl), [StatsModels.jl](https://github.com/JuliaStats/StatsModels.jl), [Distributions.jl](https://github.com/JuliaStats/Distributions.jl), [GLM.jl](https://github.com/JuliaStats/GLM.jl), [Turing.jl](https://github.com/TuringLang/Turing.jl), [Dataframes.jl](https://github.com/JuliaData/DataFrames.jl),
[LinearAlgebra.jl](https://github.com/JuliaLang/julia/tree/master/stdlib/LinearAlgebra) etc.

CRRao is a consistent framework through which callers interact with 
a large suite of models. For the end-user, it reduces the cost and complexity 
of estimating/training statistical models. It offers convenient guidelines through 
which development of additional statistical models can take place in the future.

We follow a framework which makes contribution to this package easy.

!!! note

    You can read more about **Prof C.R. Rao** [here](https://en.wikipedia.org/wiki/C._R._Rao).

## Manual

```@contents
Pages = [
    "man/guide.md",
    "man/examples.md",
]
```

## API Reference

```@contents
Pages = [
    "api/interface.md",
    "api/frequentist_regression.md",
    "api/bayesian_regression.md"
]
```